%define oname	sysdig

Name:		%{oname}
# versioning taken from https://github.com/draios/sysdig/releases
Version:	0.8.0
Release:	%mkrel 3
Summary:	sysdig
Group:		Monitoring
License:	GPLv2
URL:		http://www.sysdig.org
Source0:	https://github.com/draios/%{oname}/archive/%{version}/%{name}-%{version}.tar.gz
# bundled dependency for base64 encoder/decoder
Source1:	http://download.draios.com/dependencies/libb64-1.2.src.zip
Patch0:		0001-fix-import.patch
BuildRequires:	cmake >= 2.8
BuildRequires:	pkgconfig(zlib)
BuildConflicts:	pkgconfig(lua)
BuildRequires:	pkgconfig(luajit)
BuildRequires:	jsoncpp-devel
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(openssl)
# the kernel module is only required for live tracing, not for analysing traces
Recommends:	dkms-%{oname}

%description
Sysdig is open source, system-level exploration: capture system state and
activity from a running Linux instance, then save, filter and analyze.
Think of it as strace + tcpdump + lsof + awesome sauce.
With a little Lua cherry on top.

Sysdig instruments your physical and virtual machines at the OS level
by installing into the Linux kernel and capturing system calls and other
OS events. Then, using sysdig's command line interface, you can filter and 
decode these events in order to extract useful information. Sysdig can be used
to inspect systems live in real-time, or to generate trace files that can be
analyzed at a later stage.


%package -n dkms-%{oname}
Summary:	Kernel module required for live tracing, built via dkms
Group:		System/Kernel and hardware
Provides:	kmod(%{oname}.ko) = %{version}
Requires(pre):	dkms
Requires(post):	dkms
BuildArch:	noarch

%description -n dkms-%{oname}
Sysdig is open source, system-level exploration: capture system state and
activity from a running Linux instance, then save, filter and analyze.
Think of it as strace + tcpdump + lsof + awesome sauce.
With a little Lua cherry on top.

Sysdig instruments your physical and virtual machines at the OS level
by installing into the Linux kernel and capturing system calls and other
OS events. Then, using sysdig's command line interface, you can filter and 
decode these events in order to extract useful information. Sysdig can be used
to inspect systems live in real-time, or to generate trace files that can be
analyzed at a later stage.

This package uses DKMS to automatically build the %{oname} kernel module.

%prep
%setup -qn %{oname}-%{version}
%autopatch -p1

install -D %{SOURCE1} build/b64-prefix/src/libb64-1.2.src.zip

%build
# disable driver build, handled in -dkms subpackage, also disable build of bundled libraries
%cmake -DBUILD_DRIVER=OFF \
       -DUSE_BUNDLED_B64=ON \
       -DUSE_BUNDLED_CURL=OFF \
       -DUSE_BUNDLED_DEPS=OFF \
       -DUSE_BUNDLED_JSONCPP=OFF \
       -DUSE_BUNDLED_LUAJIT=OFF \
       -DUSE_BUNDLED_ZLIB=OFF \
       -DUSE_BUNDLED_NCURSES=OFF \
       -DUSE_BUNDLED_OPENSSL=OFF \
       -DCMAKE_BUILD_TYPE=Release

%make_build


%install
%make_install -C build

mv %{buildroot}/usr/%{_sysconfdir} %{buildroot}/%{_sysconfdir}
rm -rf %{buildroot}/usr/share/zsh/

## below is the dkms module

mv %{buildroot}/usr/src/sysdig* %{buildroot}/%{_usrsrc}/%{oname}-%{version}-%{release}


%post -n dkms-%{oname}
dkms add -m %{oname} -v %{version}-%{release} --rpm_safe_upgrade &&
dkms build -m %{oname} -v %{version}-%{release} --rpm_safe_upgrade &&
dkms install -m %{oname} -v %{version}-%{release} --rpm_safe_upgrade --force
true
/sbin/modprobe %{oname}-probe

%preun -n dkms-%{oname}
dkms remove --binary -m %{oname} -v %{version}-%{release} --rpm_safe_upgrade --all
true
/sbin/rmmod %{oname}-probe

%files
%{_bindir}/*%{oname}*
%{_datadir}/%{oname}
%{_mandir}/man8/*sysdig*
%{_sysconfdir}/bash_completion.d/%{oname}

%files -n dkms-%{oname}
%{_usrsrc}/%{oname}-%{version}-%{release}


%changelog
* Mon Jan 02 2017 akien <akien> 0.8.0-3.mga6
+ Revision: 1079581
- Rebuild for libjsoncpp changed soname

* Fri May 13 2016 daviddavid <daviddavid> 0.8.0-2.mga6
+ Revision: 1015006
- add patch from debian to fix FTBFS due to missing math.h includes
- use a named versionned tarball from github

  + tv <tv>
    - use std macros for building

* Fri Mar 11 2016 tmb <tmb> 0.8.0-1.mga6
+ Revision: 989296
- update to 0.8.0 for kernel 4.4+ support

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Mon Dec 07 2015 stormi <stormi> 0.5.1-2.mga6
+ Revision: 908703
- Fix URL in spec file

* Mon Nov 23 2015 doktor5000 <doktor5000> 0.5.1-1.mga6
+ Revision: 905026
- new version 0.5.1
  o fixes build of sysdig-probe module with 4.3 kernels
- disabled build of more bundled dependencies, use system ones
  o openssl
  o curl
- prevent download of required dependency b64

* Tue Oct 06 2015 doktor5000 <doktor5000> 0.2.0-1.mga6
+ Revision: 886635
- added BuildRequires on ncurses-devel
- new version 0.2.0
  o new ncurses user interface csysdig (added in 0.1.101)
  o new script sysdig-probe-loader (added in 0.1.98)
- disabled usage of bundled ncurses and use system ncurses

* Tue Aug 25 2015 cjw <cjw> 0.1.89-4.mga6
+ Revision: 869355
- rebuild with gcc 5

* Wed Oct 15 2014 umeabot <umeabot> 0.1.89-3.mga5
+ Revision: 747848
- Second Mageia 5 Mass Rebuild

* Tue Oct 07 2014 doktor5000 <doktor5000> 0.1.89-2.mga5
+ Revision: 737417
- added BuildRequires on pkgconfig(luajit)
  o added BuildConflicts on pkgconfig(lua)
- removed useless Recommends on luajit binary

* Tue Oct 07 2014 doktor5000 <doktor5000> 0.1.89-1.mga5
+ Revision: 737365
- switch cmake build type to Release to try to fix build
- new version 0.1.89
  o added chisel shellshock_detect: detects shellshock injections
  o added chisel spy_file: Intercepts all reads and writes to all files
- initially imported for Mageia

